# -*- coding: utf-8 -*-


def update_by_timeinterval(participations, start, end, indicators):
    res = []
    for pn in participations:
        if pn.get("start_date") > end:
            # dont export at all
            continue
        if pn.get("end_date") is not None \
                and pn.get("end_date") < pn.get("start_date"):
            # dont export broken virtual pn
            continue
        if pn.get("end_date") is None or pn.get("end_date") > end:
            # dont export result part
            pn["end_date"] = None
            pn["status_end_measure"] = None
            # remove ris for pn
            for field in [i[0] for i in indicators["RI"]]:
                pn[field] = None
        res.append(pn)
    return res


def xml_teilnehmerDatenImport(out, vorhaben_guid, data, oi_fields, ri_fields,
                              loeschliste=None):
    # out is ref to an empty list
    # vorhaben is the guid of the vorhaben
    # data is a list of enriched virtual particiption
    # fields is a list of the oi and ri indicators of the program
    out.append('<?xml version="1.0" encoding="UTF-8" standalone="yes"?>')
    out.append('<teilnehmerDatenImport xmlns="http://www.dates-esf.de/1.4">')
    out.append('<GUID>' + str(vorhaben_guid) + '</GUID>')
    if data:
        xml_TeilnehmerDatenListe(out, data, oi_fields, ri_fields)
    if loeschliste:
        xml_teilnehmerLoeschList(out, loeschliste)
    out.append('</teilnehmerDatenImport>')


def xml_TeilnehmerDatenListe(out, data, oi_fields, ri_fields):
    out.append('<TeilnehmerDatenList>')
    for d in data:
        xml_TeilnehmerDaten(out, d, oi_fields, ri_fields)
    out.append('</TeilnehmerDatenList>')


def xml_TeilnehmerDaten(out, d, oi_fields, ri_fields):
    ignored_ri = False
    out.append('<TeilnehmerDaten>')
    out.append('<teilnehmerId>' + str(d.get('personal_id')) +
               '</teilnehmerId>')
    out.append('<datesId>' + str(d.get('participant_uuid')) + '</datesId>')
    out.append('<vorsystemId>' + str(d.get('participant_uuid'))
               + '</vorsystemId>')
    if d.get('status_end_measure') is not None:
        out.append('<hatAbgebrochen>' + (
                   'true' if d.get('status_end_measure') == 1 else 'false') +
                   '</hatAbgebrochen>')
    if d.get('end_date'):
        out.append('<austrittsdatumIst>' + str(d.get('end_date')) +
                   '</austrittsdatumIst>')
    else:
        ignored_ri = True
    if d.get('planned_end_date'):
        out.append('<austrittsdatumPlan>' + str(d.get('planned_end_date')) +
                   '</austrittsdatumPlan>')
    if d.get('start_date'):
        out.append('<eintrittsdatum>' + str(d.get('start_date')) +
                   '</eintrittsdatum>')
    gender_map = {1: 'm', 0: 'f'}
    out.append('<geschlecht>' + gender_map.get(d.get('gender'), 'm') +
               '</geschlecht>')
    out.append('<einverstaendnis>true</einverstaendnis>')
    if ignored_ri:
        fields = oi_fields
    else:
        fields = oi_fields + ri_fields
    xml_IndikatorTypTeilnehmerList(out, d, fields)
    out.append('</TeilnehmerDaten>')


def xml_IndikatorTypTeilnehmerList(out, d, fields):
    out.append('<IndikatorTypTeilnehmerList>')
    for field in fields:
        out.append('<IndikatorTypTeilnehmer>' +
                   xml_IndicatorRelevance(d, field) +
                   '<IndikatorTyp><opNummer>' + field +
                   '</opNummer></IndikatorTyp></IndikatorTypTeilnehmer>')
    out.append('</IndikatorTypTeilnehmerList>')


def xml_IndicatorRelevance(d, field):
    if d.get(field) is None:
        value_str = 'k. A.'
    elif d.get(field):
        value_str = 'ja'
    else:
        value_str = 'nein'
    return '<indikatorenrelevanz>' + value_str + '</indikatorenrelevanz>'


def xml_teilnehmerLoeschList(out, loeschliste):
    out.append("<TeilnehmerLoeschList>")
    for d in loeschliste:
        xml_teilnehmerLoeschKennzeichen(out, d)
    out.append("</TeilnehmerLoeschList>")


def xml_teilnehmerLoeschKennzeichen(out, d):
    out.append("<TeilnehmerLoeschkennzeichen>")
    out.append("<teilnehmerId>" + d.get("personal_id") + "</teilnehmerId>")
    out.append("<vorsystemId>" + d.get("participant_uuid") + "</vorsystemId>")
    out.append("<guid>" + d.get("participant_uuid") + "</guid>")
    out.append("</TeilnehmerLoeschkennzeichen>")
